@@ -1,6 +1,6 @@
 #!/usr/bin/env /home/bits/CursoIngles/Curso_de_Ingles_vm5_2022/programas_auxiliares/audIG/.venv/bin/python3.10
-from paths import Caminhos
-from mixer import TocarAudios
+from audig import Caminhos
+from audig import TocarAudios
 
 
 def run() -> None:
